#include <iostream>
#include <cstdint>
#include <vector>

const uint32_t INF = 1e9;

struct Point {
	uint32_t x, y;
	Point(uint32_t x = 0, uint32_t y = 0): x(x), y(y) {}
	uint32_t colour() const {
		return (x + y) % 2;
	}
};

struct Cell {
	uint32_t comp;
	std::vector<Cell*> edges;

	Cell(): comp(INF) {}
	void dfs() {
		for (Cell* c : edges) {
			if (c->comp != INF) {
				continue;
			}
			c->comp = comp;
			c->dfs();
		}
	}
};

const uint32_t H_CNT = 8;
const uint32_t MAX_N = 105;

uint32_t dX[] = {1, 2, (uint32_t) -1, (uint32_t) -2, 1, 2, (uint32_t) -1, (uint32_t) -2};
uint32_t dY[] = {2, 1, 2, 1, (uint32_t) -2, (uint32_t) -1, (uint32_t) -2, (uint32_t) -1};

uint32_t w, h, maxJump;

bool empty[MAX_N][MAX_N];

void input() {
	std::ios::sync_with_stdio(false);
	std::cin.tie(nullptr);

	std::cin >> h >> w >> maxJump;
	for (uint32_t y = 0;y < h;y++) {
		for (uint32_t x = 0;x < w;x++) {
			char c;
			std::cin >> c;
			empty[x][y] = c == '.';
		}
	}
}

Cell cells[MAX_N][MAX_N];
std::vector<std::vector<Point>> comp;

void build_graph() {
	for (uint32_t x = 0;x < w;x++) {
		for (uint32_t y = 0;y < h;y++) {
			if (!empty[x][y]) {
				continue;
			}

			for (uint32_t d = 0;d < H_CNT;d++) {
				uint32_t nX = x + dX[d];
				uint32_t nY = y + dY[d];

				if ((nX >= w) || (nY >= h)) {
					continue;
				}
				if (!empty[nX][nY]) {
					continue;
				}
				cells[x][y].edges.push_back(&cells[nX][nY]);
			}
		}
	}
}

void build_components() { 
	uint32_t cCnt = 0;
	for (uint32_t x = 0;x < w;x++) {
		for (uint32_t y = 0;y < h;y++) {
			if ((!empty[x][y]) || (cells[x][y].comp < INF)) {
				continue;
			}
			cells[x][y].comp = cCnt++;
			cells[x][y].dfs();
		}
	}

	comp.resize(cCnt);
	
	for (uint32_t x = 0;x < w;x++) {
		for (uint32_t y = 0;y < h;y++) {
			if (!empty[x][y]) {
				continue;
			}
			comp[cells[x][y].comp].push_back(Point(x, y));
		}
	}
}

std::vector<Point> ans;

void build_ans(const std::vector<Point> &c) {
	if (c.size() == 1) {
		ans.push_back(c[0]);
		return;
	}
	std::vector<Point> col[2];
	for (const Point &i : c) {
		col[i.colour()].push_back(i);
	}
	uint32_t xorM = col[0].size() > col[1].size();
	for (uint32_t i = 0;i < 2 * maxJump + 1;i++) {
		for (const Point &j : col[(i & 1) ^ xorM]) {
			ans.push_back(j);
		}
	}
}

void print_ans() {
	std::cout << ans.size() << "\n";
	for (const Point &p : ans) {
		std::cout << p.y << " " << p.x << "\n";
	}
}

int main() {
	input();
	build_graph();
	build_components();
	for (const auto &i : comp) {
		build_ans(i);
	}
	print_ans();
}
