//take a seat, young Skywalker
#include <iostream>
#include <cstdint>
#include <algorithm>
#include <vector>
#include <cassert>

struct Person {
	uint32_t i;
	uint32_t a, b;
	Person(uint32_t a = 0, uint32_t b = 0): a(a), b(b) {}
	friend bool operator< (const Person &a, const Person &b) {
		return false;
	}

	static bool compare_a(const Person &a, const Person &b) {
		return a.a > b.a;
	}
	uint64_t eval(uint64_t x) const {
		return a + b * x;
	}
};

struct Node {
	uint32_t low, high;
	Node *l, *r;
	Person p;

	Node (uint32_t low = 0, uint32_t high = 0): low(low), high(high) {}
	Node* clone() {
		Node *ans = new Node(low, high);
		ans->l = l;
		ans->r = r;
		ans->p = p;
		return ans;
	}

	//0 if no replace, 1 if better left, 2 if better right,
	//3 if replace, 4 if not better left, 5 if not better right;
	//a is the original, b is the new one

	static Node* insert(Node *on, const Person &p, bool clone = true) {
		Node *n;
		if (clone) {
			n = on->clone();
		} else {
			n = on;
		}
		
		uint32_t mid = (n->low + n->high) / 2;

		uint64_t nl = n->p.eval(n->low);
		uint64_t nh = n->p.eval(n->high);
		uint64_t nm = n->p.eval(mid);

		uint64_t pl = p.eval(n->low);
		uint64_t ph = p.eval(n->high);
		uint64_t pm = p.eval(mid);

		if (nm >= pm) {
			if (pl > nl) {
				if (n->l) {
					n->l = insert(n->l, p);
				} else {
					n->l = insert(new Node(n->low, mid - 1), p, false);
				}
			} else if (ph > nh) {
				if (n->r) {
					n->r = insert(n->r, p);
				} else {
					n->r = insert(new Node(mid + 1, n->high), p, false);
				}
			} 
		} else {
			if (nl > pl) {
				if (n->l) {
					n->l = insert(n->l, n->p);
				} else {
					n->l = insert(new Node(n->low, mid - 1), n->p, false);
				}

			} else if (nh > ph) {
				if (n->r) {
					n->r = insert(n->r, n->p);
				} else {
					n->r = insert(new Node(mid + 1, n->high), n->p, false);
				}
			} 
			n->p = p;
		}
		return n;
	}

	std::pair<uint64_t, Person> eval (uint64_t x) const {
		uint32_t mid = (low + high) / 2;
		auto ans = std::pair<uint64_t, Person>(p.eval(x), p);
		if ((x < mid) && (l != nullptr)) {
			ans = std::max(ans, l->eval(x));
		} 
		if ((x > mid) && (r != nullptr)) {
			ans = std::max(ans, r->eval(x));
		}
		return ans;
	}
};

std::vector<Node*> prefTree;
std::vector<Node*> suffTree;

std::vector<Person> people;

uint64_t l;

void build_trees() {
	Node *pref = new Node(0, l);
	prefTree.resize(people.size());

	for (uint32_t i = 0;i < people.size();i++) {
		Person p(0, people[i].b);
		p.i = i;
		pref = Node::insert(pref, p);
		prefTree[i] = pref;
	}

	Node *suff = new Node(0, l);
	suffTree.resize(people.size());

	for (uint32_t i = people.size() - 1;i < people.size();i--) {
		people[i].i = i;
		suff = Node::insert(suff, people[i]);
		suffTree[i] = suff;
	}
}

void input() {
	std::ios::sync_with_stdio(false);
	std::cin.tie(nullptr);

	uint32_t n;
	std::cin >> n >> l;
	people.resize(n);
	for (Person &i : people) {
		std::cin >> i.a >> i.b;
	}
}

uint64_t solve_1() {
	uint64_t ans = 0;
	for (const Person &p : people) {
		uint64_t cur = p.a + p.b * (l - 1);
		ans = std::max(ans, cur);
	}
	return ans;
}

uint64_t solve_k_slow(uint32_t k) {
	if (k > l) {
		return 0;
	}
	if (k == 1) {
		return solve_1();
	}

	uint64_t baseS = 0;

	uint32_t s1 = 0, s2 = 0;
	uint64_t b1 = 0, b2 = 0;

	for (uint32_t i = 0;i < k;i++) {
		baseS += people[i].a;
		uint64_t cB = (l - k) * people[i].b;
		if (cB > b1) {
			b2 = b1;
			s2 = s1;

			b1 = cB;
			s1 = i;
		} else if (cB > b2) {
			b2 = cB;
			s2 = i;
		}
	}


	uint64_t bb1 = 0, bb2 = 0;
	for (uint32_t i = k;i < people.size();i++) {
		uint64_t cB = (l - k) * people[i].b + people[i].a;

		if (cB > bb1) {
			bb2 = bb1;
			bb1 = cB;
		} else if (cB > bb2) {
			bb2 = cB;
		}
	}
	

	//no swap
	uint64_t ans = b1 + b2 + baseS;

	uint64_t cur;

	//swap both
	cur = baseS;
	cur -= people[k - 1].a + people[k - 2].a;
	cur += bb1 + bb2;
	ans = std::max(ans, cur);

	//swap one with bottom
	cur = baseS;
	cur -= people[k - 1].a;
	cur += bb1;
	if (s1 != k - 1) {
		cur += b1;
	} else {
		cur += b2;
	}
	ans = std::max(ans, cur);

	//swap one with second bottom;
	cur = baseS;
	cur -= people[k - 2].a;
	cur += bb1;
	if (s1 != k - 2) {
		cur += b1;
	} else {
		cur += b2;
	}
	ans = std::max(ans, cur);


	return ans;
}

uint64_t solve_k(uint32_t k) {
	if (k > l) {
		return 0;
	}
	if (k == 1) {
		return solve_1();
	}

	uint64_t baseS = 0;

	uint32_t s1 = 0, s2 = 0;
	uint64_t b1 = 0, b2 = 0;

	for (uint32_t i = 0;i < k;i++) {
		baseS += people[i].a;
		uint64_t cB = (l - k) * people[i].b;
		if (cB > b1) {
			b2 = b1;
			s2 = s1;

			b1 = cB;
			s1 = i;
		} else if (cB > b2) {
			b2 = cB;
			s2 = i;
		}
	}


	uint64_t bb1 = 0, bb2 = 0;
	for (uint32_t i = k;i < people.size();i++) {
		uint64_t cB = (l - k) * people[i].b + people[i].a;

		if (cB > bb1) {
			bb2 = bb1;
			bb1 = cB;
		} else if (cB > bb2) {
			bb2 = cB;
		}
	}
	

	//no swap
	uint64_t ans = b1 + b2 + baseS;

	uint64_t cur;

	//swap both
	cur = baseS;
	cur -= people[k - 1].a + people[k - 2].a;
	cur += bb1 + bb2;
	ans = std::max(ans, cur);

	//swap one with bottom
	cur = baseS;
	cur -= people[k - 1].a;
	cur += bb1;
	if (s1 != k - 1) {
		cur += b1;
	} else {
		cur += b2;
	}
	ans = std::max(ans, cur);

	//swap one with second bottom;
	cur = baseS;
	cur -= people[k - 2].a;
	cur += bb1;
	if (s1 != k - 2) {
		cur += b1;
	} else {
		cur += b2;
	}
	ans = std::max(ans, cur);


	return ans;
}


int main() {
	input();
	std::sort(people.begin(), people.end(), Person::compare_a);
	build_trees();
	for (uint32_t i = 1;i <= people.size();i++) {
		std::cout << solve_k(i) << "\n";
	}
}



