#include<iostream>
#include<vector>
#include<algorithm>

using namespace std;

const int MAXN = 1e5 + 5;
const double inf = 1e15 + 5;

struct line
{
    double a, b;
    int index;
};

double cross(line A, line B)
{
    if(A.a==B.a) return inf;
    return (B.b-A.b)/(A.a-B.a);
}

bool operator <(const line A, const line B)
{
    if(A.a!=B.a) return A.a<B.a;
    return A.b>B.b;
}

int n;
long long L;
pair <long long, long long> a[MAXN];

vector <line> l, v;

long long tree[MAXN*4];

void build(int l, int r, int index)
{
    if(l==r)
    {
        tree[index] = a[l].first;
        return;
    }

    build(l, (l+r)/2, 2*index);
    build((l+r)/2+1, r, 2*index+1);
    tree[index] = tree[2*index] + tree[2*index+1];
}

long long query(int l, int r, int ql, int qr, int index)
{
    if(ql>qr) return 0;

    if(l>=ql && r<=qr) return tree[index];
    if(r<ql || l>qr) return 0;

    return query(l, (l+r)/2, ql, qr, 2*index) + query((l+r)/2+1, r, ql, qr, 2*index+1);
}

void update(int l, int r, int q, int index, long long value)
{
    if(l==r && l==q)
    {
        tree[q] = value;
        return;
    }
    if(r<q || l>q) return;

    update(l, (l+r)/2, q, 2*index, value);
    update((l+r)/2+1, r, q, 2*index+1, value);

    tree[index] = tree[2*index] + tree[2*index+1];
}

int bestLine(double x)
{
    if(cross(v[ v.size() - 1 ], v[ v.size() - 2 ]) <= x)
    {
        return v[ v.size() - 1 ].index;
    }

    int l = 0, r = v.size() - 2, mid;

    while(l+1<r)
    {
        mid = (l+r)/2;

        if(cross(v[mid], v[mid+1]) >= x) r = mid;
        else l = mid + 1;
    }

    if(cross(v[l], v[l+1]) >= x) return v[l].index;
    return v[r].index;
}

long long answer[MAXN];

pair <int, int> bruteForce(int i, int lOpt, int rOpt)
{
    int help1, help2, found;
    long long output = 0, option1;

    for(int index = lOpt;index<=rOpt;index++)
    {
        for(int index1 = index+1;index1<=rOpt;index1++)
        {
            /*
            option1 = (L-i)*a[index].second + a[index].first;
            option1 += (L-i)*a[index1].second + a[index1].first;

            update(0, n-1, index, 1, 0);
            update(0, n-1, index1, 1, 0);

            if(index<n-i)
            {
                if(index1<n-i)
                {
                    option1 += query(0, n-1, n-i+2, n-1, 1);
                }
                else
                {
                    option1 += query(0, n-1, n-i-1+2, n-1, 1);
                }
            }
            else if(index>=n-i)
            {
                option1 += query(0, n-1, n-i-2+2, n-1, 1);
            }

            update(0, n-1, index, 1, a[index].first);
            update(0, n-1, index1, 1, a[index1].first);
            */

            found = 2;
            for(int j = n-1;j>=0;j--)
            {
                if(found>=i) break;
                if(j==index || j==index1)
                {
                    continue;
                }

                found++;
                option1 += a[j].first;
            }

            if(output < option1)
            {
                help1 = index;
                help2 = index1;
                output = option1;
            }
        }
    }

    return {help1, help2};
}

void solve(int l, int r, int lOpt, int rOpt)
{
    if(l>r) return;

    int mid = (l+r)/2;
    auto x = bruteForce(mid, lOpt, rOpt);

    answer[mid] = (L-mid)*a[x.first].second + a[x.first].first;
    answer[mid] += (L-mid)*a[x.second].second + a[x.second].first;

    int found = 2;
    for(int j = n-1;j>=0;j--)
    {
        if(found>=mid) break;
        if(j==x.first || j==x.second)
        {
            continue;
        }

        found++;
        answer[mid] += a[j].first;
    }

    solve(l, mid-1, lOpt, x.first);
    solve(mid+1, r, x.first, rOpt);
}

int main()
{
    ios::sync_with_stdio(false);
    cin.tie(NULL);

    int index, found, index1;
    long long option1 = 0, toAdd, option2;

    int help1, help2;

    cin >> n >> L;
    for(int i = 0;i<n;i++)
    {
        cin >> a[i].first >> a[i].second;
    }

    sort(a, a+n);
    build(0, n-1, 1);

    if(n==1)
    {
        cout << (L-1)*a[0].second + a[0].first << '\n';
        return 0;
    }

    /*
    for(int i = 0;i<n;i++)
    {
        l.push_back({a[i].second, a[i].first, i});
    }
    sort(l.begin(), l.end());

    v.push_back(l[0]);
    v.push_back(l[1]);
    for(int i = 2;i<n;i++)
    {
        while(v.size()>=2 && cross(v[ v.size() - 1 ], v[ v.size() - 2 ])>=cross(v[ v.size() - 2 ], l[i]))
        {
            v.pop_back();
        }

        v.push_back(l[i]);
    }
    */

    for(int i = 1;i<=1;i++)
    {
        if(i>L)
        {
            cout << "0" << '\n';
            continue;
        }

        //index = bestLine(L-i);
        //last = a[index].first + (L-i)*a[index].second;

        if(i==1)
        {
            answer[1] = 0;
            for(index = 0;index<n;index++)
            {
                option1 = (L-i)*a[index].second + a[index].first;

                found = 1;
                for(int j = n-1;j>=0;j--)
                {
                    if(found>=i) break;
                    if(j==index)
                    {
                        continue;
                    }

                    found++;
                    option1 += a[j].first;
                }

                answer[1] = max(answer[1], option1);
            }

            cout << answer[1] << '\n';
        }
    }

    solve(2, min( (long long)n, L), 0, n-1);

    for(int i = 2;i<=min( (long long)n, L);i++)
    {
        cout << answer[i] << '\n';
    }
    for(int i = L+1;i<=n;i++)
    {
        cout << "0" << '\n';
    }
}
/*
9 1000
100 50
7 8
2 3
2 300
80 5
3 4
1 1000
9 6
6 9
*/
