#include <iostream>
#include <fstream>
#include <vector>
#include <set>
#include <map>
#include <bitset>
#include <deque>
#include <queue>
#include <iomanip>
#include <algorithm>
#include <functional>
#include <numeric>
#include <string>
#include <cstring>
#include <cassert>
#include <random>
#define ll long long
#define ld long double
#define null NULL
#define all(a) a.begin(), a.end()

using namespace std;

template<class iterator> void output(iterator begin, iterator end, ostream &out = cerr) {
	while (begin != end) {
		out << (*begin) << " ";
		begin++;
	}
	out << endl;
}

template<class T> void output(T x, ostream &out = cerr) {
	output(x.begin(), x.end(), out);
}

template<class T> int chkmax(T &a, const T &b) {
	if (b > a) {
		a = b;
		return 1;
	}
	return 0;
}

template<class T> int chkmin(T &a, const T &b) {
	if (b < a) {
		a = b;
		return 1;
	}
	return 0;
}

void fast_io() {
	ios_base::sync_with_stdio(0);
	cin.tie(0);
	cout.tie(0);
}

struct vertex_cover {
	vector<vector<int> > g;
	vector<int> ptr, covered, used, used2;
	int n, m;

	vertex_cover() {}

	void init(int _n, int _m) {
		n = _n;
		m = _m;
		cerr << "init " << n << " " << m << endl;
		g.resize(n);
		ptr.resize(m, -1);
		used.resize(n);
		used2.resize(m);
	}

	void add_edge(int u, int v) {
		cerr << "add_edge " << u << " " << v << endl;
		g[u].push_back(v);
	}

	int kuhn(int v) {
		if (used[v]) {
			return 0;
		}
		used[v] = 1;
		for (auto v1 : g[v]) {
			used2[v1] = 1;
			if (ptr[v1] == -1) {
				ptr[v1] = v;
				return 1;
			}
		}
		for (auto v1 : g[v]) {
			used2[v1] = 1;
			if (kuhn(ptr[v1])) {
				ptr[v1] = v;
				return 1;
			}
		}
		return 0;
	}

	void solve(vector<int> &a, vector<int> &b) {
		for (int i = 0; i < n; ++i) {
			fill(used.begin(), used.end(), 0);
			kuhn(i);
		}

		covered.resize(n);
		for (int i = 0; i < m; ++i) {
			if (ptr[i] != -1) {
				covered[ptr[i]] = 1;
			}
		}

		fill(used.begin(), used.end(), 0);
		fill(used2.begin(), used2.end(), 0);
		for (int i = 0; i < n; ++i) {
			if (used[i] == 0 && covered[i] == 0) {
				kuhn(i);
			}
		}

		for (int i = 0; i < n; ++i) {
			used[i] = 1 - used[i];
		}

		/*cerr << "solved" << endl;
		output(used);
		output(used2);*/

		a = used;
		b = used2;
	}
};

const int mx = 110;
int n, m, k, a[mx][mx], used[mx][mx];
vector<pair<int, int> > d = {{1, 2}, {-1, 2}, {1, -2}, {-1, -2},
{2, 1}, {-2, 1}, {2, -1}, {-2, -1}};
vector<pair<int, int> > g[mx][mx];

vector<pair<int, int> > clr0, clr1, ans;

void push_to_ans(vector<pair<int, int> > &cur) {
	for (auto pp : cur) {
		ans.push_back(pp);
	}
}

void dfs(int x, int y, int color) {
	used[x][y] = 1;
	if (color == 0) {
		clr0.push_back({x, y});
	}
	else {
		clr1.push_back({x, y});
	}
	for (auto pp : d) {
		int x1 = x + pp.first;
		int y1 = y + pp.second;
		if (0 <= x1 && x1 < n && 0 <= y1 && y1 < m && a[x1][y1] == 0) {
			g[x][y].push_back({x1, y1});
			if (used[x1][y1] == 0) {
				dfs(x1, y1, 1 - color);
			}
		}
	}
}

void go(int x, int y) {
	dfs(x, y, 0);

	if (clr0.size() + clr1.size() == 1) {
		push_to_ans(clr0);
		push_to_ans(clr1);
	}
	else {
		vector<pair<int, int> > in, out;

		if (k % 2 == 1) {
			map<pair<int, int>, int> mp;
			for (int i = 0; i < clr1.size(); ++i) {
				mp[clr1[i]] = i;
			}

			vector<int> used0, used1;
			vertex_cover solver;
			solver.init(clr0.size(), clr1.size());

			for (int i = 0; i < clr0.size(); ++i) {
				for (auto pp : g[clr0[i].first][clr0[i].second]) {
					solver.add_edge(i, mp[pp]);
				}
			}

			solver.solve(used0, used1);

			for (int i = 0; i < clr0.size(); ++i) {
				if (used0[i]) {
					in.push_back(clr0[i]);
				}
				else {
					out.push_back(clr0[i]);
				}
			}

			for (int i = 0; i < clr1.size(); ++i) {
				if (used1[i]) {
					in.push_back(clr1[i]);
				}
				else {
					out.push_back(clr1[i]);
				}
			}

			push_to_ans(in);
		}
		else {
			in = clr0;
			out = clr1;
		}

		for (int i = 0; i < k / 2 + 1; ++i) {
			push_to_ans(out);
			push_to_ans(in);
		}
	}


	clr0.clear();
	clr1.clear();
}

int main() {
	fast_io();
	cin >> n >> m >> k;
	for (int i = 0; i < n; ++i) {
		for (int j = 0; j < m; ++j) {
			char c;
			cin >> c;
			if (c == '.') {
				a[i][j] = 0;
			}
			else {
				a[i][j] = 1;
			}
		}
	}

	for (int i = 0; i < n; ++i) {
		for (int j = 0; j < m; ++j) {
			if (used[i][j] == 0 && a[i][j] == 0) {
				go(i, j);
			}
		}
	}

	cout << ans.size() << '\n';
	for (auto pp : ans) {
		cout << pp.first << " " << pp.second << '\n';
	}
}
